@@ -17,6 +17,7 @@ import _damo_subproc
 import _damo_sysinfo
 import _damon
 import _damon_args
+import _damon_modules
 import damo_report_access
 
 traceevent_damon_aggregated = 'damon_aggregated'
@@ -98,37 +99,6 @@ class DamonStatSnapshot:
             ('aggr_interval_us', aggr_interval_us),
             ])
 
-    @classmethod
-    def capture(cls, live_only=False):
-        damon_stat_parm_dir = '/sys/module/damon_stat/parameters'
-        if not os.path.isdir(damon_stat_parm_dir):
-            return None, 'damon_stat unsupported'
-        if live_only:
-            with open(os.path.join(damon_stat_parm_dir, 'enabled'), 'r') as f:
-                if f.read().strip().lower() == 'n':
-                    return None, 'damon_stat is not enabled'
-        with open(os.path.join(damon_stat_parm_dir,
-                               'memory_idle_ms_percentiles'), 'r') as f:
-            idletime_ms_percentiles = DamonIdleMsPercentiles(
-                    percentile_ms_list=[
-                        DamonIdleMsPercentile(percentile, idle_ms)
-                        for percentile, idle_ms in
-                        enumerate(f.read().strip().split(','))])
-        with open(os.path.join(damon_stat_parm_dir,
-                               'estimated_memory_bandwidth'), 'r') as f:
-            memory_bw_bytes_per_sec = int(f.read())
-        aggr_interval_file = os.path.join(damon_stat_parm_dir,
-                                          'aggr_interval_us')
-        if not os.path.isfile(aggr_interval_file):
-            aggr_interval_us = None
-        else:
-            with open(aggr_interval_file, 'r') as f:
-                aggr_interval_us = int(f.read())
-        return DamonStatSnapshot(
-                idletime_ms_percentiles=idletime_ms_percentiles,
-                memory_bw_bytes_per_sec=memory_bw_bytes_per_sec,
-                aggr_interval_us=aggr_interval_us), None
-
 class DamonSnapshot:
     '''
     Contains a snapshot of data access monitoring results
@@ -1248,8 +1218,23 @@ def start_damon_tracing(handle):
         cmd = [perf_cmd, 'record', '-o', '%s.profile' % handle.file_path]
         handle.perf_profile_pipe = subprocess.Popen(cmd)
 
+def can_record_from_damon_stat():
+    if not _damo_sysinfo.damon_feature_available('interface/damon_stat'):
+        return False
+    if not _damo_sysinfo.damon_feature_available('stat/aggr_interval'):
+        return False
+    return _damon_modules.damon_stat_running()
+
+def is_for_damon_stat(record_handle):
+    kdamonds = record_handle.kdamonds
+    return len(kdamonds) == 1 and kdamonds[0].interface == 'damon_stat'
+
 def record_source_is_running(record_handle):
-    if record_handle.snapshot_request is not None and damon_stat_avail():
+    if record_handle.snapshot_request is not None and \
+            can_record_from_damon_stat():
+        return True
+    if is_for_damon_stat(record_handle) and \
+            _damon_modules.damon_stat_running():
         return True
     return poll_target_pids(record_handle.kdamonds) or \
             _damon.any_kdamond_running()
@@ -1719,17 +1704,6 @@ class SnapshotRequest:
         self.total_sz_only = total_sz_only
         self.dont_merge_regions = dont_merge_regions
 
-def damon_stat_avail():
-    param_dir = '/sys/module/damon_stat/parameters/'
-    aggr_interval_us_file = os.path.join(param_dir, 'aggr_interval_us')
-    if not os.path.isfile(aggr_interval_us_file):
-        return False
-    enabled_file = os.path.join(param_dir, 'enabled')
-    with open(enabled_file, 'r') as f:
-        if f.read().strip().lower() == 'n':
-            return False
-    return True
-
 def should_get_snapshot_from_damon_stat(request):
     if request.tried_regions_of is not None:
         return False
@@ -1739,15 +1713,11 @@ def should_get_snapshot_from_damon_stat(request):
     if _damon.any_kdamond_running():
         return False
 
-    return damon_stat_avail()
-
-def read_damon_stat_param(param_name):
-    file_path = os.path.join('/sys/module/damon_stat/parameters', param_name)
-    with open(file_path, 'r') as f:
-        return f.read().strip()
+    return can_record_from_damon_stat()
 
 def get_snapshot_records_of_damon_stat(request):
-    aggr_interval_us = int(read_damon_stat_param('aggr_interval_us'))
+    aggr_interval_us = int(
+            _damon_modules.read_damon_stat_param('aggr_interval_us'))
     sample_interval_us = aggr_interval_us / 20
     snapshot_intervals = _damon.DamonIntervals(
             sample=sample_interval_us, aggr=aggr_interval_us,
@@ -1762,7 +1732,8 @@ def get_snapshot_records_of_damon_stat(request):
 
     snapshot_end_time_ns = time.time() * 1000000000
     snapshot_start_time_ns = snapshot_end_time_ns - aggr_interval_us * 1000
-    idle_ms_percentiles = read_damon_stat_param('memory_idle_ms_percentiles')
+    idle_ms_percentiles = _damon_modules.read_damon_stat_param(
+            'memory_idle_ms_percentiles')
     idle_ms_percentiles = [int(x) for x in idle_ms_percentiles.split(',')]
 
     mem_total_bytes = None
