@@ -32,6 +32,7 @@ import damo_record_info
 import damo_replay
 import damo_report
 import damo_schemes
+import damo_setup_cli_completion
 import damo_start
 import damo_stop
 import damo_tune
@@ -64,6 +65,9 @@ subcmds = [
             msg='control DAMON_LRU_SORT'),
 
         # For convenient use of damo and DAMON
+        _damo_subcmds.DamoSubCmd(
+            name='setup_cli_completion', module=damo_setup_cli_completion,
+            msg='setup command line auto-completion'),
         _damo_subcmds.DamoSubCmd(
             name='help', module=damo_help,
             msg='provide help for given topics'),
@@ -115,6 +119,10 @@ class SubCmdHelpFormatter(argparse.RawDescriptionHelpFormatter):
         return parts
 
 def main():
+    invoked_for_cli_complete = damo_setup_cli_completion.handle_cli_complete()
+    if invoked_for_cli_complete:
+        return
+
     parser = argparse.ArgumentParser(formatter_class=SubCmdHelpFormatter)
     parser.description = 'Control DAMON and show its results'
 
