@@ -16,6 +16,8 @@ import _damo_records
 import _damo_subproc
 import _damon
 import _damon_args
+import _damon_modules
+import damo_pa_layout
 
 class DataForCleanup:
     kdamonds_idxs = None
@@ -48,8 +50,10 @@ def sighandler(signum, frame):
     cleanup_exit(signum)
 
 def handle_args(args):
-    if _damon.any_kdamond_running() and not args.deducible_target:
-        args.deducible_target = 'ongoing'
+    if not args.deducible_target:
+        if _damon.any_kdamond_running() or \
+                _damo_records.can_record_from_damon_stat():
+            args.deducible_target = 'ongoing'
 
     args.output_permission, err = _damo_records.parse_file_permission_str(
             args.output_permission)
@@ -68,6 +72,19 @@ def handle_args(args):
         if os.path.isfile(footprint_file_path):
             os.rename(footprint_file_path, footprint_file_path + '.old')
 
+def get_ongoing_kdamonds(sysfs_kdamonds):
+    if _damon.any_kdamond_running():
+        return sysfs_kdamonds
+
+    kdamonds, err = _damon_modules.damon_stat_kdamonds()
+    if err is None:
+        return kdamonds
+
+    print('DAMON is not turned on via sysfs.')
+    print('DAMON_STAT is also unavailable (%s).' % err)
+    print('No way to proceed for ongoing kdamonds recording.')
+    exit(1)
+
 def tracepoints_from_args(args):
     if not 'access' in args.do_record or args.snapshot is not None:
         return None
@@ -190,14 +207,9 @@ def main(args):
 
     # Now the real works
     if _damon_args.is_ongoing_target(args):
-        if not _damon.any_kdamond_running():
-            print('DAMON is not turned on')
-            exit(1)
-
+        kdamonds = get_ongoing_kdamonds(data_for_cleanup.orig_kdamonds)
         # TODO: Support multiple kdamonds, multiple contexts
-        monitoring_intervals = data_for_cleanup.orig_kdamonds[
-                0].contexts[0].intervals
-        kdamonds = data_for_cleanup.orig_kdamonds
+        monitoring_intervals = kdamonds[0].contexts[0].intervals
     elif for_damon_stat_snapshot(args):
         monitoring_intervals = _damon.DamonIntervals(
                 sample=5000, aggr=100000, ops_update=60000000,
