@@ -1776,6 +1776,9 @@ def read_and_show(args):
             exit(1)
         if signal_received is True:
             break
+        if len(records) == 0 and args.input_file is not None and \
+                repeat_count == 1:
+            print('No record in %s' % args.input_file)
 
         if args.exec:
             err = handle_exec(args.exec, records)
@@ -2018,11 +2021,15 @@ def set_argparser(parser):
                 '"tried_regions_of <kdamond idx> <context idx> <scheme idx>"'
                 ]))
     parser.add_argument('--input_file', metavar='<file>', nargs='+',
-            help='source of the access pattern to show')
-    parser.add_argument('--tried_regions_of', nargs=3, type=int,
-            action='append',
+                        # source of the access pattern to show
+                        # suppress in favor of --input.
+                        help=argparse.SUPPRESS)
+    parser.add_argument(
+            '--tried_regions_of', nargs=3, type=int, action='append',
             metavar=('<kdamond idx>', '<context idx>', '<scheme idx>'),
-            help='show tried regions of given schemes')
+            # show tried regions of given schemes
+            # suppress in favor of --input.
+            help=argparse.SUPPRESS)
     _damo_records.set_snapshot_damos_filters_option(parser)
     add_fmt_args(parser, hide_help=True)
 
